Developer reference
===================

This section is intended for those that want to contribute to the metasyn package, or simply want a deeper understanding of how it works. It contains the classes, functions and modules that are not in the rest of the reference API. These are mostly elements that are not directly used by users, but are important for developers of the metasyn package to understand the architecture.

DistSpec
^^^^^^^^

.. autoclass:: metasyn.varspec.DistributionSpec
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.config module
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.config
   :members:
   :undoc-members:
   :show-inheritance:


metasyn.registry module
^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.registry
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.var module
^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.var
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.testutils module
^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.testutils
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.validation module
^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.validation
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.privacy module
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.privacy
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.util module
^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.util
   :members:
   :undoc-members:
   :show-inheritance:

metasyn.file module
^^^^^^^^^^^^^^^^^^^
.. automodule:: metasyn.file
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:

metasyn.distribution.base module
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: metasyn.distribution.base
   :members:
   :show-inheritance:
   :private-members:

